
#todo: log from here - but how???
## pass log to the error class? or vice versa?

class Rhaptos2Error(Exception):
    '''PLaceholder excpetion - lets find out what mistakes we make then iterate '''
    pass



